From 57acf88e22b715686a46a52edca9be25eb9a9aec Mon Sep 17 00:00:00 2001
From: Christoph Grueninger <christoph.grueninger@iws.uni-stuttgart.de>
Date: Fri, 23 Nov 2012 12:28:55 +0000
Subject: [PATCH] Fix Doxygen warnings introduced by the inclusion of 2pdfm.

git-svn-id: svn://svn.iws.uni-stuttgart.de/DUMUX/dumux/trunk@9633 2fb0f335-1f38-0410-981e-8018bf24f1b0
---
 dumux/boxmodels/2pdfm/2pdfmvolumevariables.hh | 13 +++++++------
 dumux/io/artmeshreader.hh                     |  3 +--
 test/boxmodels/2pdfm/2pdfmspatialparams.hh    |  3 ++-
 test/boxmodels/2pdfm/2pdfmtestproblem.hh      |  6 +++---
 4 files changed, 13 insertions(+), 12 deletions(-)

diff --git a/dumux/io/artmeshreader.hh b/dumux/io/artmeshreader.hh
index c65bc669c8..be77711f96 100644
--- a/dumux/io/artmeshreader.hh
+++ b/dumux/io/artmeshreader.hh
@@ -89,7 +89,7 @@ public:
     /*!
      * \brief Reads the file formats obtained with the Artmesh generator
      * 
-     * \param
+     * \param artFileName Path to the Artmesh file.
      */
     void read_art_file(const char *artFileName)
     {
@@ -508,7 +508,6 @@ public:
      * \brief Constructor
      * 
      * \param grid The grid
-     * \param geomArt Artmesh reader
      */
     FractureMapper (const GridType& grid)
         : grid_(grid),
diff --git a/test/boxmodels/2pdfm/2pdfmspatialparams.hh b/test/boxmodels/2pdfm/2pdfmspatialparams.hh
index 75f164553c..425476ece7 100644
--- a/test/boxmodels/2pdfm/2pdfmspatialparams.hh
+++ b/test/boxmodels/2pdfm/2pdfmspatialparams.hh
@@ -310,7 +310,7 @@ public:
      * \brief Returns the width of the fracture.
      * 
      * \param element The current element
-     * \param globalFaceIdx Face index of which the width is returned
+     * \param localFaceIdx Local face index of which the width is returned
      */
     Scalar fractureWidth(const Element &element, int localFaceIdx) const
     {
@@ -338,6 +338,7 @@ public:
      * 
      * \param isDuneFractureVertex Vector of bools which indicates fracture vertices
      * \param isDuneFractureEdge Vector of bools which indicates fracture edges
+     * \param fractureEdgesIdx Vector of edge indices which are fractures
      * \param inactivateFractures Deactivates fractures
      */
     const void setFractureBoolVectors(const std::vector<bool>& isDuneFractureVertex,
diff --git a/test/boxmodels/2pdfm/2pdfmtestproblem.hh b/test/boxmodels/2pdfm/2pdfmtestproblem.hh
index e15f9ed968..e36bf1159f 100644
--- a/test/boxmodels/2pdfm/2pdfmtestproblem.hh
+++ b/test/boxmodels/2pdfm/2pdfmtestproblem.hh
@@ -105,14 +105,14 @@ SET_BOOL_PROP(TwoPDFMTestProblem, ProblemEnableGravity, false);
  * \brief Soil contamination problem involving a DNAPL migration into a
  *        fully water saturated media
  *
- * This problem uses the \ref TwoPBoxDFMModel.
+ * This problem uses the \ref TwoPDFMModel.
  *
  * This problem should typically be simulated until \f$t_{\text{end}}
  * \approx 100\,000\;s\f$ is reached. A good choice for the initial time step
  * size is \f$t_{\text{inital}} = 1\;s\f$.
  *
  * To run the simulation execute the following line in shell:
- * <tt>./test_2pDFM grids/defaultgrid.net 1e6 1
+ * <tt>./test_2pDFM grids/defaultgrid.net 1e6 1</tt>
  */
 template <class TypeTag >
 class TwoPDFMTestProblem : public PorousMediaBoxProblem<TypeTag>
@@ -164,7 +164,7 @@ public:
      * \param gridView The grid view
      * \param isDuneFractureVertex Vector of bools which indicates fracture vertices
      * \param isDuneFractureEdge Vector of bools which indicates fracture edges
-     * \param inactivateFractures Deactivates fractures
+     * \param fractureEdgesIdx Vector of edge indices which are fractures
      */
     TwoPDFMTestProblem(TimeManager &timeManager,
                        const GridView &gridView,
diff --git a/dumux/boxmodels/2pdfm/2pdfmvolumevariables.hh b/dumux/boxmodels/2pdfm/2pdfmvolumevariables.hh
index c49cce37b5..520d902aa3 100644
--- a/dumux/boxmodels/2pdfm/2pdfmvolumevariables.hh
+++ b/dumux/boxmodels/2pdfm/2pdfmvolumevariables.hh
@@ -85,14 +85,14 @@ public:
                 const Element &element,
                 const FVElementGeometry &fvGeometry,
                 int scvIdx,
-                bool oldSol)
+                bool isOldSol)
     {
         ParentType::update(priVars,
                            problem,
                            element,
                            fvGeometry,
                            scvIdx,
-                           oldSol);
+                           isOldSol);
 
         this->completeFluidState(priVars, problem, element, fvGeometry, scvIdx, fluidState_);
 
@@ -111,8 +111,8 @@ public:
         porosityMatrix_ = problem.spatialParams().porosity(element, fvGeometry, scvIdx);
 
         // energy related quantities not belonging to the fluid state
-        asImp_().updateEnergy_(priVars, problem, element, fvGeometry, scvIdx, oldSol);
-        asImp_().updateFracture(priVars, problem, element, fvGeometry, scvIdx, oldSol);
+        asImp_().updateEnergy_(priVars, problem, element, fvGeometry, scvIdx, isOldSol);
+        asImp_().updateFracture(priVars, problem, element, fvGeometry, scvIdx, isOldSol);
     }
 
     /*!
@@ -122,14 +122,15 @@ public:
      * \param problem The problem which needs to be simulated.
      * \param element The DUNE Codim<0> entity for which the volume variables ought to be calculated
      * \param fvGeometry The finite volume geometry of the element
      * \param oldSol Tells whether the model's previous or current solution should be used.
      */
     void updateFracture(const PrimaryVariables &priVars,
                         const Problem &problem,
                         const Element &element,
                         const FVElementGeometry &fvGeometry,
                         int scvIdx,
-                        bool oldSol)
+                        bool isOldSol)
     {
         PrimaryVariables varsFracture;
         const MaterialLawParams &materialParamsMatrix =
@@ -122,14 +122,15 @@ public:
      * \param element The DUNE Codim<0> entity for which the volume variables ought to be calculated
      * \param fvGeometry The finite volume geometry of the element
-     * \param oldSol Tells whether the model's previous or current solution should be used.
+     * \param scvIdx Sub-control volume index
+     * \param isOldSol Tells whether the model's previous or current solution should be used.
      */
     void updateFracture(const PrimaryVariables &priVars,
-- 
GitLab